/* Copyright 2023 Oliver Smith, Arnaud Ferraris
 * SPDX-License-Identifier: MPL-2.0
 *                  _     _ _                             __ _
 *  _ __ ___   ___ | |__ (_) | ___        ___ ___  _ __  / _(_) __ _
 * | '_ ` _ \ / _ \| '_ \| | |/ _ \_____ / __/ _ \| '_ \| |_| |/ _` |
 * | | | | | | (_) | |_) | | |  __/_____| (_| (_) | | | |  _| | (_| |
 * |_| |_| |_|\___/|_.__/|_|_|\___|      \___\___/|_| |_|_| |_|\__, |
 * mobile-config-firefox                                        |___/
 * https://gitlab.postmarketos.org/postmarketOS/mobile-config-firefox/
 *
 * WARNING: DO NOT EDIT THE COPY OF THIS FILE LOCATED IN YOUR USER PROFILE!
 *
 * It will be overwritten on upgrade. You should edit the files located in
 * /etc/mobile-config-firefox/ instead (most package managers won't replace
 * files under /etc if they've been edited). Or alternatively, consider cloning
 * mobile-config-firefox.git and editing the separate CSS files there.
 * Patches for useful additions welcome!
 */
